@@ -130,7 +130,7 @@ class Dsl(Contract):
             pricer=pricer,
         )
         for market in pricerCode.getMarkets():
-            estimatedDelta = pricerCode.calcDelta(estimatedValue, market)
+            estimatedDelta = pricerCode.calcDelta(market)
             self.saveResult(
                 result=result,
                 metricName=result.DELTA_METRIC,
@@ -138,7 +138,7 @@ class Dsl(Contract):
                 market=market,
                 pricer=pricer,
             )
-            estimatedGamma = pricerCode.calcGamma(estimatedValue, estimatedDelta, market)
+            estimatedGamma = pricerCode.calcGamma(market)
             self.saveResult(
                 result=result,
                 metricName=result.GAMMA_METRIC,
