@@ -47,7 +47,7 @@ class Market(SimpleObject):
         yearAbbr = str(self.firstDeliveryDate.year)[2:]
         return self.symbol.getLabelValue() + '.' + monthLetter + yearAbbr
 
-    def getLastPrice(self, observationTime):
+    def calcLastPrice(self, observationTime):
         # Todo: Look up effective value at observation time.
         return self.lastPrice
 
@@ -56,12 +56,6 @@ class Market(SimpleObject):
         return ([i for i in self.temporalHistory])
 
 
-class PriceProcess(DatedStatefulObject):
-
-    package = String()
-    name = String()
-    
-
 class Image(SimpleObject):
 
     isUnique = False
@@ -82,20 +76,36 @@ class Image(SimpleObject):
         elif len(metrics) == 1:
             metricValue = metrics[0].metricValue
         else:
-            metricValue = self.deriveMetricValue(metricName=metricName, market=market)
+            metricValue = self.priceProcess.getMetricValue(metricName=metricName, market=market, observationTime=self.observationTime)
             self.metrics.create(metricValue=metricValue, metricName=metricName, market=market)
         return metricValue
 
-    def deriveMetricValue(self, metricName, market):
-        if metricName == 'last-price':
-            value = market.getLastPrice(observationTime=self.observationTime)
-        elif metricName == 'actual-historical-volatility':
-            priceHistory = market.getPriceHistory(observationTime=self.observationTime)
-            value = self.priceProcess.calcActualHistoricalVolatility(priceHistory)
-        else:  
-            raise Exception, "Market metric name '%s' not supported." % (metricName)
+    def perturbMetric(self, metricName, market, factor):
+        return PerturbedImage(self, metricName, market, factor)
+
+
+class PerturbedImage(object):
+
+    def __init__(self, originalImage, metricName, market, factor):
+        self.originalImage = originalImage
+        self.metricName = metricName
+        self.market = market
+        self.factor = factor
+
+    def __getattribute__(self, item):
+        if item in ['getMetricValue', 'getPerturbation', 'originalImage', 'metricName', 'market', 'factor']:
+            return object.__getattribute__(self, item)
+        return getattr(self.originalImage, item)
+
+    def getMetricValue(self, metricName, market):
+        value = self.originalImage.getMetricValue(metricName, market)
+        if metricName == self.metricName and market == self.market:
+            value += self.factor * value
         return value
 
+    def getPerturbation(self):
+        return self.factor * self.originalImage.getMetricValue(self.metricName, self.market)
+
 
 class Metric(SimpleObject):
 
