@@ -15,7 +15,7 @@ class Result(SimpleDatedObject):
 
     PRESENT_VALUE_METRIC = 'value'
     DELTA_METRIC = 'delta'
-    GAMMA_METRIC = 'gama'
+    GAMMA_METRIC = 'gamma'
     VEGA_METRIC = 'vega'
 
     isUnique = False
@@ -70,6 +70,8 @@ class Result(SimpleDatedObject):
         marketVegas = {}
         greeks = [self.DELTA_METRIC, self.GAMMA_METRIC, self.VEGA_METRIC]
         for line in self.lines:
+            if not line.market:
+                continue
             market = line.market
             if market not in markets:
                 markets.append(market)
