@@ -18,7 +18,8 @@ class TestResult(TestCase):
 
     def setUp(self):
         self.image = self.registry.images.findDomainObjects()[-1]
-        self.book = self.registry.books.read(title='My Book')
+        self.book = self.registry.books.values()[0]
+        self.failUnlessEqual(self.book.title, "My Book")
         self.result = self.registry.results.create(book=self.book, image=self.image)
 
     def tearDown(self):
