@@ -4,6 +4,7 @@ import quant.domtest
 import quant.priceprocess.test
 import quant.contracttype.test
 import quant.pricer.test
+import quant.leastsquarestest
 
 def suite():
     suites = [
@@ -12,6 +13,7 @@ def suite():
         quant.priceprocess.test.suite(),
         quant.contracttype.test.suite(),
         quant.pricer.test.suite(),
+        quant.leastsquarestest.suite(),
     ]
     return unittest.TestSuite(suites)
 
